@@ -18,6 +18,7 @@
  */
 
 #include "app-store-base.h"
+#include "app-store-click.h"
 #include "app-store-legacy.h"
 #ifdef HAVE_LIBERTINE
 #include "app-store-libertine.h"
@@ -43,6 +44,8 @@ Base::~Base()
 std::list<std::shared_ptr<Base>> Base::allAppStores(const std::shared_ptr<Registry::Impl>& registry)
 {
     return {
+        std::make_shared<Click>(registry) /* Click */
+        ,
         std::make_shared<Legacy>(registry) /* Legacy */
         ,
 #ifdef HAVE_LIBERTINE
